@@ -118,12 +118,12 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.13.3';
+	return '2.16.1';
   }
 
   function MinimumCMSVersion()
   {
-	return '1.9.2';
+	return '1.10.2';
   }
 
   function GetAdminDescription()
@@ -277,6 +277,16 @@ EOT;
 						 array('action'=>'hierarchy','returnid'=>$hierpage));
   }
 
+  public function LazyLoadFrontend()
+  {
+	return FALSE;
+  }  
+
+  public function LazyLoadAdmin()
+  {
+	return TRUE;
+  }
+
   function InstallPostMessage()
   {
 	return $this->Lang('postinstall');
@@ -326,15 +336,19 @@ EOT;
   {
 	return $this->lang('eventhelp-' . $eventname);
   }
-	
+
+  function HandlersEvents()
+  {
+	return TRUE;
+  }
+
 
   /*---------------------------------------------------------
    DoAction()
    ---------------------------------------------------------*/
   function DoAction($name,$id,$params,$returnid='')
   {
-    global $gCms;
-    $smarty =& $gCms->GetSmarty();
+    $smarty = cmsms()->GetSmarty();
 
     $smarty->assign_by_ref('mod',$this);
     $smarty->assign('returnid',$returnid);
@@ -361,10 +375,10 @@ EOT;
 	
 
   // deprecated
-  function GetCategory($category_id,$full = false)
+  function &GetCategory($category_id,$full = false)
   {
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$gCms = cmsms();
+	$db = $gCms->GetDb();
 	$config = $gCms->GetConfig();
 
 	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_categories WHERE id = ?';
@@ -396,8 +410,8 @@ EOT;
   // deprecated
   function GetCategories($full = false)
   {
-	global $gCms;
-	$db =& $gCms->GetDB();
+	$gCms = cmsms();
+	$db = $gCms->GetDB();
 	$config = $gCms->GetConfig();
 		
 	if( count($this->_category_cache) )
@@ -442,8 +456,8 @@ EOT;
   {
 	$entryarray = array();
 
-	global $gCms;
-	$db =& $gCms->GetDB();
+	$gCms = cmsms();
+	$db = $gCms->GetDB();
 	
 	$entryarray = $this->GetCategories($full);
 
@@ -545,9 +559,8 @@ EOT;
   // deprecated, move to class
   function GetFieldDefsForProduct($id,$admin = false,$public = true)
   {
-
-	global $gCms;
-	$db =& $gCms->GetDB();
+	$gCms = cmsms();
+	$db = $gCms->GetDB();
 		
 	$entryarray = $this->GetFieldDefs($admin,$public);
 
@@ -674,7 +687,7 @@ EOT;
   {
 	if( !isset($this->_product_cache[$id]) )
 	  {
-		$db =& $this->GetDb();
+		$db = $this->GetDb();
 		$query = "SELECT * FROM ".cms_db_prefix()."module_products
                      WHERE id = ?";
 		$row = $db->GetRow( $query, array( $id ) );
@@ -690,7 +703,7 @@ EOT;
   function GetProductAttributes($product_id)
   {
 	$results = array();
-	$db =& $this->GetDb();
+	$db = $this->GetDb();
 	$query = "SELECT * FROM ".cms_db_prefix()."module_products_attribsets
                WHERE product_id = ?";
 	$dbresult = $db->Execute($query,array($product_id));
@@ -703,6 +716,7 @@ EOT;
 
 
   // deprecated
+  // ready to remove now?
   function GetProductAttributeDataComplete($product_id)
   {
 	$db = $this->GetDb();
@@ -749,8 +763,7 @@ EOT;
 		$names[$i] = trim(trim($names[$i]),"'");
 	  }
 
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$db = cmsms()->GetDb();
 
 	// convert names to category ids.
 	$query = 'SELECT id FROM '.cms_db_prefix().'module_products_categories
@@ -775,8 +788,8 @@ EOT;
 		$hier_str = str_replace($delim,' | ',$hier_str);
 	  }
 	
-	global $gCms;
-	$db =& $gCms->GetDb();
+	$gCms = cmsms();
+	$db = $gCms->GetDb();
 	$hierarchies = array();
 	if( endswith($hier_str,'*') )
 	  {
@@ -809,8 +822,7 @@ EOT;
   // deprecated, move to ops
   function UpdateHierarchyPositions()
   {
-	$this->_load_admin();
-	return products_UpdateHierarchyPositions($this);
+	return product_utils::update_hierarchy_positions();
   }
 
 
@@ -976,7 +988,7 @@ EOT;
 	if( !isset($params['categoryid']) ) return;
 
 	$catid = (int)$params['categoryid'];
-	$obj =& $this->GetCategory($catid);
+	$obj = $this->GetCategory($catid);
 	
 	if( isset($params['assign']) )
 	  {
