@@ -77,7 +77,7 @@ if( !empty($detailpage) )
     $node = $manager->sureGetNodeByAlias($detailpage);
     if (isset($node))
       {
-	$content =& $node->GetContent();	
+	$content = $node->GetContent();	
 	if (isset($content))
 	  {
 	    $detailpage = $content->Id();
@@ -85,7 +85,7 @@ if( !empty($detailpage) )
       }
     else
       {
-	$node =& $manager->sureGetNodeById($detailpage);
+	$node = $manager->sureGetNodeById($detailpage);
 	if (!isset($node))
 	  {
 	    $detailpage = '';
@@ -426,14 +426,12 @@ else
 
 
 
-
 // Determine the number of pages
 $npages = intval($count / $limit);
 if( $count % $limit != 0 ) $npages++;
 
 // build the object list
-global $gCms;
-$config = $gCms->GetConfig();
+$config = cmsms()->GetConfig();
 while ($dbresult && ($row = $dbresult->FetchRow()))
 {
   $filedir = cms_join_path($config['uploads_path'],$this->GetName(),'product_'.$row['id']);
@@ -487,15 +485,10 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
     }
 
   // add attributes ... deprecated.
-  $tmp = $this->GetProductAttributeDataComplete($row['id']);
-  if( is_array($tmp) )
-    {
-      $onerow->attributes = $tmp;
-    }
-
   $tmp = product_utils::get_product_attributes_full($parms['productid']);
   if( is_array($tmp) )
     {
+      $onerow->attributes = $tmp;
       $onerow->attribs_full = $tmp;
     }
 
