@@ -58,6 +58,8 @@ $fields = array();
 $name_expr = '';
 $desc_expr = '';
 $price_expr = '';
+$price_min = '';
+$price_max = '';
 $allany = 0;
 $searchdata = array();
 $where = array();
@@ -153,7 +155,7 @@ if( isset($params['sortby']) )
 	    $fieldname = substr($str,strlen('f:'));
 	    if( isset($fields[$fieldname]) )
 	      {
-		$fieldid = $fielddefs[$fieldname]->id;
+		$fieldid = $fields[$fieldname]->id;
 		$as = 'FV'.$sortfield++;
 		$joins[] = 'LEFT JOIN '.cms_db_prefix()."module_products_fieldvals {$as} ON c.id = {$as}.product_id AND $as.fielddef_id = '{$fieldid}'";
 		$sortby = "{$as}.value";
@@ -170,7 +172,18 @@ if( isset($params['cd_proddesc']) )
   {
     $desc_expr = trim($params['cd_proddesc']);
   }
-if( isset($params['cd_prodprice']) )
+if( isset($params['cd_prodprice_min']) || isset($params['cd_prodprice_max']) )
+  {
+    if( isset($params['cd_prodprice_min']) )
+      {
+	$price_min = (float)trim($params['cd_prodprice_min']);
+      }
+    if( isset($params['cd_prodprice_max']) )
+      {
+	$price_max = (float)trim($params['cd_prodprice_max']);
+      }
+  }
+else if( isset($params['cd_prodprice']) )
   {
     $price_expr = trim($params['cd_prodprice']);
     if( $price_expr == -1 ) $price_expr = '';
@@ -179,23 +192,49 @@ if( isset($params['cd_allany']) )
   {
     $allany = (int)$params['cd_allany'];
   }
-if( isset($params['cd_propvalue']) )
+
+if( isset($params['cd_prodvalue']) && !is_array($params['cd_prodvalue']) )
   {
-    if( !is_array($params['cd_propvalue']) )
-      {
-	$params['cd_propvalue'] = unserialize($params['cd_propvalue']);
-      }
-    $tfields = array_keys($params['cd_propvalue']);
-    foreach ($tfields as $one )
-      {
-	if( $params['cd_propvalue'][$one] != '-1' &&
-	    !empty($params['cd_propvalue'][$one]) )
-	  {
-	    $searchdata[$one] = trim($params['cd_propvalue'][$one]);
-	  }
-      }
-    $params['cd_propvalue'] = serialize($params['cd_propvalue']);
+    $params['cd_prodvalue'] = unserialize($params['cd_prodvalue']);
   }
+$tfields = array_keys($fields);
+foreach( $tfields as $one )
+{
+  if( isset($params['cd_prodvalue'][$one]) &&
+      $params['cd_prodvalue'][$one] != '-1' &&
+      !empty($params['cd_prodvalue'][$one]) )
+    {
+      $searchdata[$one] = trim($params['cd_prodvalue'][$one]);
+      continue;
+    }
+
+  $key1 = 'cd_prodvalue_'.$one.'_min';
+  $key2 = 'cd_prodvalue_'.$one.'_max';
+  if( isset($params[$key1]) || isset($params[$key2]) )
+    {
+      $tdata = array('min'=>'','max'=>'');
+      if( isset($params[$key1]) )
+	{
+	  $tdata['min'] = (float)trim($params[$key1]);
+	}
+      if( isset($params[$key2]) )
+	{
+	  $tdata['max'] = (float)trim($params[$key2]);
+	}
+
+      if( $tdata['min'] != $tdata['max'] ) 
+	{
+	  if( $tdata['min'] > $tdata['max'] )
+	    {
+	      $tmp = $tdata['max'];
+	      $tdata['max'] = $tdata['min'];
+	      $tdata['min'] = $tmp;
+	    }
+
+	  $searchdata[$one] = $tdata;
+	}
+    }
+}
 
 // build the query
 if( !empty($name_expr) )
@@ -208,7 +247,36 @@ if( !empty($desc_expr) )
     $where[] = 'P.details REGEXP ?';
     $qparms[] = $desc_expr;
   }
-if( !empty($price_expr) )
+if( $price_min != '' || $price_max != '' )
+  {
+    if( $price_min != '' && $price_max != '' )
+      {
+	if( $price_max != $price_min )
+	  {
+	    if( $price_min > $price_max )
+	      {
+		$tmp = $price_max;
+		$price_max = $price_min;
+		$price_min = $tmp;
+	      }
+
+	    $where[] = '(P.price BETWEEN ? AND ?)';
+	    $qparms[] = $price_min;
+	    $qparms[] = $price_max;
+	  }
+      }
+    else if( $price_min != '' )
+      {
+	$where[] = '(P.price >= ?)';
+	$qparms[] = $price_min;
+      }
+    else if( $price_max != '' )
+      {
+	$where[] = '(P.price <= ?)';
+	$qparms[] = $price_max;
+      }
+  }
+else if( !empty($price_expr) )
   {
     list($low,$high) = explode(':',$price_expr,2);
     $low = (float)$low;
@@ -225,9 +293,34 @@ if( !empty($searchdata) )
     $joins[] = 'LEFT JOIN '.cms_db_prefix().'module_products_fieldvals FV ON P.id = FV.product_id';
     foreach( $searchdata as $propname => $propval )
       {
-	$where[] = '(FV.fielddef_id = ? AND FV.value REGEXP ?)';
-	$qparms[] = $fields[$propname]->id;
-	$qparms[] = $propval;
+	if( !is_array($propval) )
+	  {
+	    $where[] = '(FV.fielddef_id = ? AND FV.value REGEXP ?)';
+	    $qparms[] = $fields[$propname]->id;
+	    $qparms[] = $propval;
+	  }
+	else 
+	  {
+	    if( $propval['min'] != '' && $propval['max'] != '' )
+	      {
+		$where[] = '(FV.fielddef_id = ? AND FV.value BETWEEN ? AND ?)';
+		$qparms[] = $fields[$propname]->id;
+		$qparms[] = $propval['min'];
+		$qparms[] = $propval['max'];
+	      }
+	    else if( $propval['min'] != '' )
+	      {
+		$where[] = '(FV.fielddef_id = ? AND FV.value >= ?)';
+		$qparms[] = $fields[$propname]->id;
+		$qparms[] = $propval['min'];
+	      }
+	    else if ($propval['max'] != '' )
+	      {
+		$where[] = '(FV.fielddef_id = ? AND FV.value <= ?)';
+		$qparms[] = $fields[$propname]->id;
+		$qparms[] = $propval['max'];
+	      }
+	  }
       }
   }
 
