@@ -155,18 +155,20 @@ else
 //     return;
 //   }
 
-
 $hierdata = '';
 if( count($data) == 1 && empty($nodes) )
   {
     $data = $data[0];
-    $query = 'SELECT * FROM '.cms_db_prefix().'module_products_hierarchy WHERE id = ?';
-    $hierdata = $db->GetRow($query,array($data['id']));
   }
 $smarty->assign('hierdata',$data);
-if( $hierdata )
+if( count($parents) == 1 )
   {
-    $smarty->assign('hierarchy_item',$hierdata);
+    $hierdata = hierarchy_ops::get_hierarchy_info($parents[0]);
+    if( $hierdata )
+      {
+	$hierdata['canonical'] = $this->CreatePrettyLink($id,'hierarchy',$returnid,'',array('parent'=>$parents[0]),'',true);
+	$smarty->assign('hierarchy_item',$hierdata);
+      }
   }
 $smarty->assign('hierarchy_image_location',$config['uploads_url'].'/'.$this->GetName().'/hierarchy');
 
