@@ -39,7 +39,7 @@
 if( !isset($gCms) ) return;
 
 
-$contentops =& $gCms->GetContentOperations();
+$contentops = $gCms->GetContentOperations();
 $sortorder = $this->GetPreference('sortorder','asc');
 $sortby = $this->GetPreference('sortby','product_name');
 
