@@ -13,6 +13,7 @@ $lang['add_category_field'] = 'Associate Field with Category: &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Add Hierarchy Item';
 $lang['add_option'] = 'Add Attribute Option';
 $lang['admin_only'] = 'Can only admins see this attribute?';
+$lang['advanced'] = 'Advanced';
 $lang['align_ul'] = 'Top Left';
 $lang['align_uc'] = 'Top Center';
 $lang['align_ur'] = 'Top Right';
@@ -32,6 +33,7 @@ $lang['attribute_name'] = 'Attribute Name';
 $lang['automatic'] = 'Automatic';
 
 # B
+$lang['btn_setecomhandlers'] = 'Set Ecommerce Event Handlers';
 $lang['byhierarchytemplates'] = 'Hierarchy Report Templates';
 $lang['byhierarchytemplate_addedit'] = 'Add/Edit Hierarchy Report Template';
 
@@ -98,6 +100,7 @@ $lang['error_missingparam'] = 'A required parameter is missing or invalid';
 $lang['error_nameused'] = 'An item by that name is already in use';
 $lang['error_nofieldtype'] = 'Please select a field type';
 $lang['error_noname'] = 'You must supply a name';
+$lang['error_onequantityfield'] = 'Only one quantity field is allowed';
 $lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
 $lang['error_permissiondenied'] = 'Permission Denied';
 $lang['error_product_aliasused'] = 'The alias specified is already in use';
@@ -116,6 +119,7 @@ $lang['extra2'] = 'Extra Field 2';
 
 # F
 $lang['field'] = 'Field';
+$lang['fields'] = 'Fields';
 $lang['fielddef'] = 'Field Definition';
 $lang['fielddefs'] = 'Field Definitions';
 $lang['file'] = 'File';
@@ -182,6 +186,28 @@ $lang['help'] = <<<EOT
    </p>
   </li>
 </ul>
+<h3>The <em>ajax_propval</em> Action</h3>
+  <p>The <em>ajax_propval</em> is a special action that is used to return the distinct values of a custom field, or a property via json.  Typically this action is used to perform autocomplete actions, and usually in conjunction with the search action.  This action accepts the parameters: field for the name of the field, and fieldval for indicating a starting value.  None of the parameters can be empty.  Below you will find a simple example of using the ajax_propval action to perform autocomplete for product names in conjunction with the search template.</p>
+<pre><code>&lt;script type="text/javascript"&gt;{literal}
+$(document).ready(function(){
+  var ajax_url = '{/literal}<span style="color: green;">{module_action_link module=Products action=ajax_propval urlonly=1 jsfriendly=1}</span>{literal}';
+  ajax_url = ajax_url + <span style="color: red;">'&showtemplate=false'</span>;
+
+  $(<span style="color: blue;">'#productname'</span>).autocomplete({
+    source: function(req,add){
+      var tmp =  ajax_url+<span style="color: red;">'&cntnt01field=::name::&cntnt01fieldval='</span>+req.term;
+      $.getJSON(tmp,function(json){
+        if( json.status == 'OK' && json.data.length > 0) {
+          add(json.data);
+        }
+      })
+    }    
+  });
+});
+{/literal}&lt;/script&gt;
+</code></pre>
+<p>As you can see from the above code snippet.. the {module_action_link} plugin from CGSimpleSmarty is used to generate a url that will trigger the ajax_propval action.  After that URL is retrieved, the showtemplate=false parameter is added to the URL.   When setting up the autocomplete plugin, the callback used to fill in the data values for the field uses ajax.  We take the ajax_url already prepared and add the field=::name:: and fieldval=req.term parameters to the URL.  The term is automatically provided by the autocomplete plugin in the req.term variiable.</p>
+<p>To use this example, the user would need to ensure that jquery is loaded, along with the jquery ui (including autocomplete), and any required stylesheets.  This could be done either in the page specific metadata field when editing the page containing the search form, or in the page template itself.</p>
 <h3>Support</h3>
 <p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
 <ul>
@@ -239,11 +265,14 @@ $lang['info_fieldproblems'] = 'Problems were encountered when dealing with one o
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
 $lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
+$lang['info_imagestuff_deprecated'] = 'Image processing functions are deprecated and will be removed in a future version.  Use CGSmartImage for inline image processing.';
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
 $lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Valid values are +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Public fields are available for the public to see';
+$lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjust the order that they will be displayed in in the hierarchy view';
+$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the products module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
 
 # J
 # K
@@ -261,6 +290,7 @@ $lang['modifieddate'] = 'Modified Date';
 $lang['module_description'] = 'A module for managing a catalog of products, their price, images, etc, and for allowing users to build a cart';
 $lang['move_down'] = 'Move Down';
 $lang['move_up'] = 'Move Up';
+$lang['msg_eventhandlers_created'] = 'Event Handlers Created';
 
 # N
 $lang['name'] = 'Name';
@@ -275,6 +305,7 @@ $lang['nothing_selectd'] = 'Nothing selected';
 
 # O
 $lang['of'] = 'Of';
+$lang['operation_cancelled'] = 'Operation Cancelled';
 $lang['operation_complete'] = 'Operation Complete';
 
 # P
@@ -294,6 +325,7 @@ Specify the behaviour of the module.  Possible values are:
      </p>
   </li>
   <li>search - Display a form to allow searching products on various criterium</li>
+<li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
 </ul>
 EOT;
 $lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified product categories.';
@@ -303,8 +335,8 @@ $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist acti
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
-$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
-$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
+$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the product name, sku and alias respectively.';
+$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
 $lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=\'trucks,cars\'}';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
@@ -356,6 +388,7 @@ $lang['product_detail_settings'] = 'Product Detail Settings';
 $lang['product_editing_settings'] = 'Product Editing Settings';
 $lang['product_summary_settings'] = 'Product Summary Settings';
 $lang['product_hierarchy'] = 'Product Hierarchy';
+$lang['product_info'] = 'Product Information';
 $lang['product_manager'] = 'Product Manager';
 $lang['progress'] = 'Progress';
 $lang['prompt'] = 'Prompt';
@@ -413,9 +446,11 @@ $lang['public'] = 'Is this a public field?';
 $lang['published'] = 'Published';
 
 # Q
+$lang['quantity_on_hand'] = 'Quantity on Hand';
 
 # R
 $lang['random'] = 'Random';
+$lang['reorder_hierarchy'] = 'Reorder Hierarchy';
 $lang['resettofactory'] = 'Reset to Factory Values';
 $lang['return'] = 'Return';
 $lang['return_to_top'] = 'Return to the top of the view';
