@@ -12,6 +12,7 @@ $lang['add_category_field'] = 'Koppel veld met categorie: &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Voeg hierarchie-artikel toe';
 $lang['add_option'] = 'Voeg attribuutoptie toe';
 $lang['admin_only'] = 'Kan alleen de administrator dit attribuut zien?';
+$lang['advanced'] = 'Geavanceerd';
 $lang['align_ul'] = 'Boven Links';
 $lang['align_uc'] = 'Boven Midden';
 $lang['align_ur'] = 'Boven Rechts';
@@ -29,6 +30,7 @@ $lang['areyousure_deleteproduct'] = 'Weet u zeker dat u dit product en alle bijb
 $lang['ascending'] = 'Oplopend';
 $lang['attribute_name'] = 'Atribuut Naam';
 $lang['automatic'] = 'Automatisch';
+$lang['btn_setecomhandlers'] = 'Ecommerce Gebeurtenissen instellen';
 $lang['byhierarchytemplates'] = 'Hierarchie Rapport Sjablonen';
 $lang['byhierarchytemplate_addedit'] = 'Hierarchie Rapport Sjabloon toevoegen/aanpassen';
 $lang['cancel'] = 'Annuleren';
@@ -87,6 +89,7 @@ $lang['error_missingparam'] = 'Een benodigde parameter mist of is niet geldig';
 $lang['error_nameused'] = 'Een item met deze naam is al in gebruik';
 $lang['error_nofieldtype'] = 'Selecteer a.u.b. een veldtype';
 $lang['error_noname'] = 'U moet een naam invoeren';
+$lang['error_onequantityfield'] = 'Er is slechts een veld met de hoeveelheid toegestaan';
 $lang['error_onesubscriptionfield'] = 'Er is &eacute;&eacute;n lidmaatschapveld toegestaan';
 $lang['error_permissiondenied'] = 'Toegang geweigerd';
 $lang['error_product_aliasused'] = 'De genoemde alias is al in gebruik';
@@ -103,6 +106,7 @@ $lang['expire_two_year'] = 'Na twee jaar';
 $lang['extra1'] = 'Extra veld 1';
 $lang['extra2'] = 'Extra veld 2';
 $lang['field'] = 'Veld';
+$lang['fields'] = 'Velden';
 $lang['fielddef'] = 'Velddefinitie';
 $lang['fielddefs'] = 'Velddefinities';
 $lang['file'] = 'Bestand';
@@ -218,11 +222,14 @@ $lang['info_fieldproblems'] = 'Er is probleem ontstaan met het verwerken van een
 $lang['info_handleimages'] = 'Als bij een import een bestandsnaam van een afbeelding wordt gevonden, moet het dan verplaatst worden van de bronlocatie, worden gewatermerkt, gethumnailed of het bestandstype worden gewijzigd naar &quot;image&quot;.';
 $lang['info_hierpage'] = 'Gebruik deze pagina voor de hie&auml;rchische weergave. De paginaid zal niet worden weergegeven in de URL.';
 $lang['info_imagepath'] = 'In dit pad (gezien vanaf de uploads-map) kunnen de afbeeldingen worden gevonden die zijn opgegeven in het ge&iuml;mporteerde bestand.';
+$lang['info_imagestuff_deprecated'] = 'De functies verwerken van afbeeldingen zijn verlopen en zullen worden verwijderd in toekomstige versies. Gebruik CGSmartImage voor het verwerken van afbeeldingen.';
 $lang['info_import_test_passed'] = 'Een korte test heeft plaatsgevonden op het geselecteerde geselecteerde bestand en alles lijkt in orde.<br/>Dit is echter geen garantie dat er geen fouten in het bestand aanwezig zijn.';
 $lang['info_prettyhierurls'] = 'Voeg de hie&auml;rchie naam toe aan de URL';
 $lang['info_price_adjustment'] = 'Geaccepteerde waarden zijn +-*#.##';
 $lang['info_prodnotfound'] = 'Deze optie bepaald het gedrag van de website wanneer een detailweergave van een product rechtstreeks wordt bezocht met een URL en dat product om een bepaalde reden (uitgeschakeld, verwijderd, etc.) niet kan worden bezocht.';
 $lang['info_publicfield'] = 'Publieke velden zijn zichtbaar voor het publiek';
+$lang['info_reorder_content'] = 'Deze actie staat het slepen van individuele items in de boomstructuur toe. Zo kunt u de volgorde aanpassen waarin de items worden weergeven in de hi&euml;rarchische weergave.';
+$lang['info_setecomhandlers'] = 'Deze knop garandeert dat de gebeurtenissen voor e-commerceactiviteiten juist zijn ge&iuml;nstalleerd. Dit is handig wanneer de productenmodule de beschikbare hoeveelheden bij wil houden, maar de gebeurtenishandlers niet zijn aangemaakt tijden de installatie of upgrade.';
 $lang['label'] = 'Label ';
 $lang['label_skip'] = 'Sla over';
 $lang['label_overwrite'] = 'Overschrijven';
@@ -234,6 +241,7 @@ $lang['modifieddate'] = 'Aangepast op';
 $lang['module_description'] = 'Een module voor het managen van een productcatalogus. De producten zijn voorzien van een prijs, een foto, etc. Ook is er een mogelijkheid voor een winkelwagen te maken.';
 $lang['move_down'] = 'Verschuif naar beneden';
 $lang['move_up'] = 'Verschuif naar boven';
+$lang['msg_eventhandlers_created'] = 'Gebeurtenishandlers gecree&euml;rd.';
 $lang['name'] = 'Naam';
 $lang['needpermission'] = 'U heeft niet de vereiste rechten: %s';
 $lang['new_category_name'] = 'Nieuwe Categorie Naam';
@@ -243,6 +251,7 @@ $lang['nonamegiven'] = 'Er is geen naam ingevuld';
 $lang['none'] = 'Geen';
 $lang['nothing_selectd'] = 'Niets geselecteerd';
 $lang['of'] = 'Van';
+$lang['operation_cancelled'] = 'Actie geannuleerd';
 $lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
@@ -264,19 +273,19 @@ $lang['param_action'] = 'Specificeer de werking van de module.  Mogelijke waarde
 $lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
 $lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
-$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
+$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used. ';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
-$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category ';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
-$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
+$lang['param_fieldval'] = 'Alleen voor de <em>standaard</em> actie, deze parameter staat toe een waarde op te geven om de resultaten bij te limiteren.  Speciale waarden voor dit veld zijn: &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
-$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
-$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
+$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used. ';
+$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline ';
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
-$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
+$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report. ';
 $lang['param_productid'] = 'Heeft alleen zin in de uitgebreide sjabloon. Deze parameter geeft aan welk product te gebruiken bij het weergeven.';
-$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored. ';
 $lang['param_resultpage'] = 'Applicable only to the search action, this parameter specifies a page id or alias to use to display the search results';
 $lang['param_searchfield'] = 'Alleen van toepassing op de zoekacties, deze parameter kan een kommagescheiden lijst bevatten met daarin veldnamen die kunnen worden toegevoegd in de zoekactie.';
 $lang['param_searchformtemplate'] = 'Alleen van toepassing op de zoekacties, deze parameter staat nu om een niet standaard zoeksjabloon te gebruiken';
@@ -298,8 +307,8 @@ $lang['param_sortby'] = 'Applicable only in the summary or search actions, this
   <li>modified -- The modified date for this company record</li>
   <li>f:fieldname -- Allows sorting by values of custom fields.</li>
 </ul>';
-$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
-$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
+$lang['param_sorttype'] = 'Alleen van toepassing op de standaard samenvattingsweergave, deze parameter kan worden gebruikt om waardes om te zetten naar een ander type voor sortering.  Geldige waarden zijn STRING, SIGNED en UNSIGNED. Als dit niet is opgegeven dan zal standaard STRING worden gekozen.';
+$lang['param_summarypage'] = 'Alleen van toepassing op action=hierarchy, staat toe op een pagina id of alias op te geven die moet worden gebruikt voor de links in de samenvattingsweergave.';
 $lang['param_summarytemplate'] = 'Deze parameter geeft aan welke opsomming sjabloon er gebruikt moet worden. Als er geen geselecteerd wordt dan word de standaard sjabloon gebruikt.';
 $lang['parent'] = 'Bovenliggende';
 $lang['postinstall'] = 'De Products module is geinstalleerd';
@@ -316,6 +325,7 @@ $lang['product_detail_settings'] = 'Product Detail Instellingen';
 $lang['product_editing_settings'] = 'Product Wijzigen instellingen';
 $lang['product_summary_settings'] = 'Productsamenvatting instellingen';
 $lang['product_hierarchy'] = 'Producthierarchie';
+$lang['product_info'] = 'Productinformatie';
 $lang['product_manager'] = 'Productmanager';
 $lang['progress'] = 'Voortgang';
 $lang['prompt'] = 'Prompt ';
@@ -371,7 +381,9 @@ $lang['prompt_usehierpathurls'] = 'Gebruik Pad Hierarchie in de Product Detail U
 $lang['prompt_weightunits'] = 'Gewichteenheid';
 $lang['public'] = 'Is dit een publiek veld?';
 $lang['published'] = 'Gepubliceerd';
+$lang['quantity_on_hand'] = 'Beschikbare hoeveelheid';
 $lang['random'] = 'Willekeurig';
+$lang['reorder_hierarchy'] = 'Herorder hierarchie';
 $lang['resettofactory'] = 'Reset naar standaardinstellingen';
 $lang['return'] = 'Keer terug';
 $lang['return_to_top'] = 'Ga terug naar de bovenkant van de pagina';
@@ -428,9 +440,9 @@ $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.805332592.1309943374.1309943374.1309943374.1';
-$lang['utmz'] = '156861353.1309794590.3.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/file_listing';
-$lang['qca'] = 'P0-1408926661-1309528475256';
+$lang['utma'] = '156861353.826990304.1314695841.1314696054.1314715138.3';
+$lang['utmz'] = '156861353.1314695841.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['qca'] = 'P0-856617467-1310370352588';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
